dat.api


clear!clj

(clear! db)
source

close!clj

(close! db)
source

connclj

(conn db)

Returns the underlying backend connection (a datalevin.core or datascript.core conn), for backend-specific operations dat.api doesn't wrap, e.g. datalevin.core/listen! or datalevin.core/entity.

Returns the underlying backend connection (a datalevin.core or
datascript.core conn), for backend-specific operations dat.api doesn't
wrap, e.g. datalevin.core/listen! or datalevin.core/entity.
sourceraw docstring

init!clj

(init! db-type schema db-opts)
source

pullclj

(pull derefed-db selector eid)
source

qclj

(q query derefed-db & args)
source

register-fn!clj

(register-fn! db ident f)

Registers a transaction function f under ident, so that tx-data entries of the form [ident & args] invoke it as a transaction function.

For :dat.db/datalevin, f must be built with datalevin.interpret/inter-fn at the call site (it needs to see the literal fn form to make it serializable), and its args are [db & args].

Registers a transaction function `f` under `ident`, so that tx-data
entries of the form `[ident & args]` invoke it as a transaction function.

For :dat.db/datalevin, `f` must be built with `datalevin.interpret/inter-fn`
at the call site (it needs to see the literal `fn` form to make it
serializable), and its args are `[db & args]`.
sourceraw docstring

transact!clj

(transact! db txs)
source

uuidclj

(uuid)
source

cljdoc builds & hosts documentation for Clojure/Script libraries